0.3.7  (2019-10-11)
-------------------

Update :

* Add a TokenGenerator to allow authentication through URL

0.3.5  (2019-09-24)
-------------------

Fixes :

* fix settings call

0.3.1  (2019-09-24)
-------------------

Update :

* add default settings for HOSTNAME and FRONT_URL

0.3.0  (2019-09-23)
-------------------

First release from splitted terracommon.core
